import React, { Component } from 'react';
import { fetchPublicCarList } from '../../api/index';
import { PullToRefresh, Toast } from 'antd-mobile';
import styles from './style.css';
import PublicCarItem from './components/PublicCarItem';

class PublicCarList extends Component {
  constructor(props) {
    super(props);
    this.state = {
      refreshing: false,
      down: true,
      height: document.documentElement.clientHeight,
      list: [],
      pagination: {
        nowDate: '',
        pageNum: 1,
        pageSize: 50,
      },
    };
  }

  componentDidMount() {
    let wrap = document.querySelector('.RepairContent');
    const hei = wrap.clientHeight;
    setTimeout(
      () =>
        this.setState({
          height: hei,
        }),
      0
    );
    this.fetchList();
  }
  fetchList = fetchMore => {
    const { pagination } = this.state;
    const nowDate = new Date().toISOString();
    const entity = fetchMore
      ? {
          ...pagination,
          pageNum: pagination.pageNum + 1,
        }
      : {
          ...pagination,
          pageNum: 1,
          nowDate,
        };
    fetchPublicCarList(entity)
      .then(res => {
        this.setState(
          ({ list, pagination }) =>
            fetchMore
              ? res.data.length
                ? {
                    list: [...list, ...res.data],
                    pagination: {
                      ...pagination,
                      pageNum: pagination.pageNum + 1,
                    },
                    refreshing: false,
                  }
                : {
                    refreshing: false,
                  }
              : {
                  list: res.data,
                  pagination: {
                    ...pagination,
                    nowDate,
                  },
                  refreshing: false,
                }
        );
      })
      .catch(err => {
        Toast.fail(err.msg || '请求失败！');
        this.setState({
          refreshing: false,
        });
      });
  };
  refreshHandle = () => {
    this.fetchList(true);
  };
  render() {
    return (
      <div className={styles.publicCarList}>
        <PullToRefresh
          damping={60}
          ref={el => (this.ptr = el)}
          style={{
            height: this.state.height,
            overflow: 'auto',
          }}
          indicator={{ deactivate: '上拉可以刷新' }}
          direction={'up'}
          refreshing={this.state.refreshing}
          onRefresh={this.refreshHandle}
        >
          <div className={styles.listInfo}>显示最近半年的报修记录</div>
          {this.state.list.length ? (
            this.state.list.map(i => <PublicCarItem key={i.id} data={i} />)
          ) : (
            <div className={styles.noData}>暂无数据</div>
          )}
        </PullToRefresh>
      </div>
    );
  }
}

export default PublicCarList;
