import React, { Component } from 'react';
import { PullToRefresh, Modal, Toast, TextareaItem } from 'antd-mobile';
import styles from './style.css';
import PublicCarItem from '../PublicCar/components/PublicCarItem';
import {
  fetchApplyPublicCarList,
  dealPublicCar,
  fetchCarPlateList,
} from '../../api/index';
// import Select from '../../components/Input/Select/Select';
import SelectIcon from './images/more_item_btn@2x.png';
import offCheckIcon from '../../images/Check/radio_off_btn@2x.png';
import onCheckIcon from '../../images/Check/radio_on_btn@2x.png';
import UserInfoContext from '../../context/userinfo-context';

class PublicCarDeal extends Component {
  constructor(props) {
    super(props);
    this.state = {
      refreshing: false,
      down: true,
      height: document.documentElement.clientHeight,
      pagination: {
        pageNum: 1,
        pageSize: 50,
      },
      list: [],
      dealDialogVisible: false,
      selected: {
        id: '',
        value: '',
        carPlate: '',
        dealOpinion: '',
      },
      carPlateList: [],
    };
  }
  componentDidMount() {
    this.fetchList();
  }
  fetchList = fetchMore => {
    this.setState({ refreshing: true });
    const { pagination } = this.state;
    const nowDate = new Date().toISOString();
    const entity = fetchMore
      ? {
          ...pagination,
          pageNum: pagination.pageNum + 1,
        }
      : {
          ...pagination,
          pageNum: 1,
          nowDate,
        };
    fetchApplyPublicCarList(entity)
      .then(res => {
        this.setState(
          ({ list, pagination }) =>
            fetchMore
              ? res.data.length
                ? {
                    list: [...list, ...res.data],
                    pagination: {
                      ...pagination,
                      pageNum: pagination.pageNum + 1,
                    },
                    refreshing: false,
                  }
                : {
                    refreshing: false,
                  }
              : {
                  list: res.data,
                  pagination: {
                    ...pagination,
                    nowDate,
                  },
                  refreshing: false,
                }
        );
      })
      .catch(err => {
        Toast.fail(err.msg || '请求失败！');
        this.setState({
          refreshing: false,
        });
      });
  };
  refreshHandle = () => {
    this.fetchList(true);
  };
  dealHandle = id => {
    if (this.state.carPlateList.length === 0) {
      fetchCarPlateList()
        .then(res => {
          this.setState(({ carPlateList }) => ({
            carPlateList: res.data.map(i => ({
              value: i.id,
              lable: i.name,
            })),
          }));
        })
        .catch(err => {
          console.log(err);
        });
    }
    this.setState(({ selected }) => ({
      dealDialogVisible: true,
      selected: {
        ...selected,
        id,
      },
    }));
  };
  resetDialog = () => {
    this.setState(({ selected }) => ({
      dealDialogVisible: false,
      selected: {
        id: '',
        value: '',
        carPlate: '',
        dealOpinion: '',
      },
    }));
  };
  toggleSelectedState = val => {
    this.setState(({ selected }) => ({
      selected: {
        ...selected,
        value: val,
      },
    }));
  };
  validateSelect = () => {
    const {
      selected: { value, carPlate },
    } = this.state;
    if (!value) {
      Toast.fail('请选择处理结果！');
      return false;
    }
    if (value === 2) {
      if (carPlate === '-1') {
        Toast.fail('请选择派车！');
        return false;
      }
    }
    return true;
  };
  submitHandle = () => {
    if (!this.validateSelect()) {
      return;
    }
    const {
      selected: { id, value, carPlate, dealOpinion },
    } = this.state;
    const { userinfo } = this.props;
    const entity =
      value === 2
        ? {
            id: id,
            dealName: userinfo.name,
            dealResult: value,
            carPlate: carPlate,
          }
        : {
            id: id,
            dealName: userinfo.name,
            dealResult: value,
            dealOpinion: dealOpinion
              ? `不同意 - ${dealOpinion}`
              : '不同意 - 无车可派送',
          };
    dealPublicCar(entity)
      .then(res => {
        this.resetDialog();
        this.fetchList();
        Toast.success(res.msg || '处理成功！');
      })
      .catch(err => {
        Toast.fail(err.msg || '处理失败！');
      });
  };
  onSelectHandle = e => {
    console.log(e);
    const val = e.target.value;
    this.setState(({ selected }) => ({
      selected: {
        ...selected,
        carPlate: val,
      },
    }));
  };
  onInputHandle = val => {
    this.setState(({ selected }) => ({
      selected: {
        ...selected,
        dealOpinion: val,
      },
    }));
  };
  render() {
    const {
      selected: { value, dealOpinion },
      dealDialogVisible,
      carPlateList,
    } = this.state;
    return (
      <PullToRefresh
        damping={60}
        ref={el => (this.ptr = el)}
        style={{
          height: this.state.height,
          overflow: 'auto',
        }}
        indicator={{ deactivate: '上拉可以刷新' }}
        direction={'up'}
        refreshing={this.state.refreshing}
        onRefresh={this.refreshHandle}
      >
        <div className={styles.listInfo}>显示最近半年的报修记录</div>
        {this.state.list.length ? (
          this.state.list.map(i => (
            <PublicCarItem key={i.id} data={i} dealHandle={this.dealHandle} />
          ))
        ) : (
          <div className={styles.noData}>暂无数据</div>
        )}
        <Modal
          className={styles.dealDialog}
          visible={dealDialogVisible}
          transparent
          maskClosable={false}
          onClose={this.resetDialog}
          title=""
          footer={[
            { text: '放弃', onPress: this.resetDialog },
            {
              text: '提交',
              onPress: this.submitHandle,
            },
          ]}
        >
          <div className={styles.dialogBody}>
            <div key="radio" className={styles.alertInfo}>
              <div
                className={styles.radioBox}
                onClick={() => this.toggleSelectedState(2)}
              >
                <span className={styles.checkLabel}>
                  {value === 2 ? (
                    <img src={onCheckIcon} alt="" />
                  ) : (
                    <img src={offCheckIcon} alt="" />
                  )}
                </span>
                <span>同意</span>
              </div>
              <div
                className={styles.radioBox}
                onClick={() => this.toggleSelectedState(3)}
              >
                <span className={styles.checkLabel}>
                  {value === 3 ? (
                    <img src={onCheckIcon} alt="" />
                  ) : (
                    <img src={offCheckIcon} alt="" />
                  )}
                </span>
                <span>不同意</span>
              </div>
            </div>
            {value === 2 ? (
              <div key="agree" className={styles.agree}>
                <span className={styles.dialogAgreeLabel}>派车车牌</span>
                <div className={styles.selectWrap}>
                  <div className={styles.selectIcon}>
                    <img src={SelectIcon} alt="" />
                  </div>
                  <select
                    className={styles.select}
                    onChange={this.onSelectHandle}
                    defaultValue="-1"
                  >
                    <option disabled value="-1" >请选择</option>
                    {carPlateList.map(i => (
                      <option key={i.value} value={i.lable}>
                        {i.lable}
                      </option>
                    ))}
                  </select>
                </div>
              </div>
            ) : value === 3 ? (
              <div key="notAgree" className={styles.notAgree}>
                <span className={styles.dialogLabel}>处理结果</span>
                <TextareaItem
                  className={styles.textarea}
                  placeholder="输入处理结果"
                  rows={3}
                  count={50}
                  value={dealOpinion}
                  onChange={this.onInputHandle}
                />
              </div>
            ) : null}
          </div>
        </Modal>
      </PullToRefresh>
    );
  }
}

export default props => (
  <UserInfoContext.Consumer>
    {({ userinfo }) => <PublicCarDeal userinfo={userinfo} {...props} />}
  </UserInfoContext.Consumer>
);
