import React, { Component } from 'react';
import { PullToRefresh, Modal, Toast } from 'antd-mobile';
import styles from './style.css';
import RepairItem from '../Repair/components/RepairItem';
import { fetchReportRepairList, dealRepair } from '../../api/index';
import Perview from '../../components/Perview/Perview';
import onCheckIcon from '../../images/Check/radio_on_btn@2x.png';

class RepairDeal extends Component {
  constructor(props) {
    super(props);
    this.state = {
      refreshing: false,
      down: true,
      height: document.documentElement.clientHeight,
      pagination: {
        nowDate: '',
        pageNum: 1,
        pageSize: 50,
      },
      list: [],
    };
  }
  componentDidMount() {
    this.fetchList();
  }
  fetchList = fetchMore => {
    this.setState({ refreshing: true });
    const { pagination } = this.state;
    const nowDate = new Date().toISOString();
    const entity = fetchMore
      ? {
          ...pagination,
          pageNum: pagination.pageNum + 1,
        }
      : {
          ...pagination,
          pageNum: 1,
          nowDate,
        };
    fetchReportRepairList(entity)
      .then(res => {
        this.setState(
          ({ list, pagination }) =>
            fetchMore
              ? res.data.length
                ? {
                    list: [...list, ...res.data],
                    pagination: {
                      ...pagination,
                      pageNum: pagination.pageNum + 1,
                    },
                    refreshing: false,
                  }
                : {
                    refreshing: false,
                  }
              : {
                  list: res.data,
                  pagination: {
                    ...pagination,
                    nowDate,
                  },
                  refreshing: false,
                }
        );
      })
      .catch(err => {
        Toast.fail(err.msg || '请求失败！');
        this.setState({
          refreshing: false,
        });
      });
  };
  refreshHandle = () => {
    this.fetchList(true);
  };
  dealHandle = id => {
    console.log('in date');
    Modal.alert(
      '',
      <div className={styles.alertInfo}>
        <span className={styles.checkLabel}>
          <img src={onCheckIcon} alt="" />
        </span>
        <span>已处理</span>
      </div>,
      [
        { text: '放弃', onPress: () => console.log('cancel') },
        {
          text: '提交',
          onPress: () =>
            dealRepair({
              id: id,
            })
              .then(res => {
                this.fetchList();
                Toast.fail(res.msg || '处理成功！');
              })
              .catch(err => {
                Toast.fail(err.msg || '处理失败！');
              }),
        },
      ]
    );
  };
  showViewHandle = (list, index) => {
    this.setState({
      perviewVisibility: true,
      perviewIndex: index,
      selectedImgList: list,
    });
  };
  resetDialog = () => {
    this.setState({
      perviewVisibility: false,
    });
  };
  render() {
    const { perviewVisibility, selectedImgList, perviewIndex } = this.state;
    return [
      <PullToRefresh
        key="repairList"
        damping={60}
        ref={el => (this.ptr = el)}
        style={{
          height: this.state.height,
          overflow: 'auto',
        }}
        indicator={{ deactivate: '上拉可以刷新' }}
        direction={'up'}
        refreshing={this.state.refreshing}
        onRefresh={this.refreshHandle}
      >
        <div className={styles.listInfo}>显示最近半年的报修记录</div>
        {this.state.list.length ? (
          this.state.list.map(i => (
            <RepairItem
              key={i.id}
              data={i}
              dealHandle={this.dealHandle}
              showView={this.showViewHandle}
            />
          ))
        ) : (
          <div className={styles.noData}>暂无数据</div>
        )}
      </PullToRefresh>,
      <Modal
        key="repairImgPerview"
        className={styles.perViewDialog}
        visible={perviewVisibility}
        transparent
        maskClosable={true}
        onClose={this.resetDialog}
        title=""
      >
        <Perview data={selectedImgList} index={perviewIndex} />
      </Modal>,
    ];
  }
}

export default RepairDeal;
